@@ -38,6 +38,7 @@ __all__ = [
     "SDL_HINT_GAMECONTROLLER_IGNORE_DEVICES_EXCEPT",
     "SDL_HINT_GAMECONTROLLER_USE_BUTTON_LABELS",
     "SDL_HINT_GRAB_KEYBOARD",
+    "SDL_HINT_HIDAPI_IGNORE_DEVICES",
     "SDL_HINT_IDLE_TIMER_DISABLED",
     "SDL_HINT_IME_INTERNAL_EDITING",
     "SDL_HINT_IME_SHOW_UI",
@@ -49,9 +50,11 @@ __all__ = [
     "SDL_HINT_JOYSTICK_GAMECUBE_RUMBLE_BRAKE",
     "SDL_HINT_JOYSTICK_HIDAPI_JOY_CONS",
     "SDL_HINT_JOYSTICK_HIDAPI_COMBINE_JOY_CONS",
+    "SDL_HINT_JOYSTICK_HIDAPI_VERTICAL_JOY_CONS",
     "SDL_HINT_JOYSTICK_HIDAPI_LUNA",
     "SDL_HINT_JOYSTICK_HIDAPI_NINTENDO_CLASSIC",
     "SDL_HINT_JOYSTICK_HIDAPI_SHIELD",
+    "SDL_HINT_JOYSTICK_HIDAPI_PS3",
     "SDL_HINT_JOYSTICK_HIDAPI_PS4",
     "SDL_HINT_JOYSTICK_HIDAPI_PS4_RUMBLE",
     "SDL_HINT_JOYSTICK_HIDAPI_PS5",
@@ -63,7 +66,14 @@ __all__ = [
     "SDL_HINT_JOYSTICK_HIDAPI_SWITCH_HOME_LED",
     "SDL_HINT_JOYSTICK_HIDAPI_JOYCON_HOME_LED",
     "SDL_HINT_JOYSTICK_HIDAPI_SWITCH_PLAYER_LED",
+    "SDL_HINT_JOYSTICK_HIDAPI_WII",
+    "SDL_HINT_JOYSTICK_HIDAPI_WII_PLAYER_LED",
     "SDL_HINT_JOYSTICK_HIDAPI_XBOX",
+    "SDL_HINT_JOYSTICK_HIDAPI_XBOX_360",
+    "SDL_HINT_JOYSTICK_HIDAPI_XBOX_360_PLAYER_LED",
+    "SDL_HINT_JOYSTICK_HIDAPI_XBOX_360_WIRELESS",
+    "SDL_HINT_JOYSTICK_HIDAPI_XBOX_ONE",
+    "SDL_HINT_JOYSTICK_HIDAPI_XBOX_ONE_HOME_LED",
     "SDL_HINT_JOYSTICK_RAWINPUT",
     "SDL_HINT_JOYSTICK_RAWINPUT_CORRELATE_XINPUT",
     "SDL_HINT_JOYSTICK_HIDAPI_CORRELATE_XINPUT",
@@ -86,6 +96,7 @@ __all__ = [
     "SDL_HINT_MOUSE_RELATIVE_MODE_WARP",
     "SDL_HINT_MOUSE_RELATIVE_SCALING",
     "SDL_HINT_MOUSE_RELATIVE_SPEED_SCALE",
+    "SDL_HINT_MOUSE_RELATIVE_SYSTEM_SCALE",
     "SDL_HINT_MOUSE_RELATIVE_WARP_MOTION",
     "SDL_HINT_MOUSE_TOUCH_EVENTS",
     "SDL_HINT_MOUSE_AUTO_CAPTURE",
@@ -105,6 +116,7 @@ __all__ = [
     "SDL_HINT_RENDER_OPENGL_SHADERS",
     "SDL_HINT_RENDER_SCALE_QUALITY",
     "SDL_HINT_RENDER_VSYNC",
+    "SDL_HINT_PS2_DYNAMIC_VSYNC",
     "SDL_HINT_RETURN_KEY_HIDES_IME",
     "SDL_HINT_RPI_VIDEO_LAYER",
     "SDL_HINT_SCREENSAVER_INHIBIT_ACTIVITY_NAME",
@@ -125,6 +137,7 @@ __all__ = [
     "SDL_HINT_VIDEO_WAYLAND_ALLOW_LIBDECOR",
     "SDL_HINT_VIDEO_WAYLAND_PREFER_LIBDECOR",
     "SDL_HINT_VIDEO_WAYLAND_MODE_EMULATION",
+    "SDL_HINT_VIDEO_WAYLAND_EMULATE_MOUSE_WARP",
     "SDL_HINT_VIDEO_WINDOW_SHARE_PIXEL_FORMAT",
     "SDL_HINT_VIDEO_FOREIGN_WINDOW_OPENGL",
     "SDL_HINT_VIDEO_FOREIGN_WINDOW_VULKAN",
@@ -208,6 +221,7 @@ SDL_HINT_VIDEO_FOREIGN_WINDOW_OPENGL = b"SDL_VIDEO_FOREIGN_WINDOW_OPENGL"
 SDL_HINT_VIDEO_FOREIGN_WINDOW_VULKAN = b"SDL_VIDEO_FOREIGN_WINDOW_VULKAN"
 SDL_HINT_VIDEO_WAYLAND_ALLOW_LIBDECOR = b"SDL_VIDEO_WAYLAND_ALLOW_LIBDECOR"
 SDL_HINT_VIDEO_WAYLAND_PREFER_LIBDECOR = b"SDL_VIDEO_WAYLAND_PREFER_LIBDECOR"
+SDL_HINT_VIDEO_WAYLAND_EMULATE_MOUSE_WARP = b"SDL_VIDEO_WAYLAND_EMULATE_MOUSE_WARP"
 SDL_HINT_VIDEO_WAYLAND_MODE_EMULATION = b"SDL_VIDEO_WAYLAND_MODE_EMULATION"
 SDL_HINT_VIDEO_WINDOW_SHARE_PIXEL_FORMAT = b"SDL_VIDEO_WINDOW_SHARE_PIXEL_FORMAT"
 SDL_HINT_VIDEO_X11_FORCE_EGL = b"SDL_VIDEO_X11_FORCE_EGL"
@@ -264,6 +278,7 @@ SDL_HINT_MOUSE_RELATIVE_MODE_CENTER = b"SDL_MOUSE_RELATIVE_MODE_CENTER"
 SDL_HINT_MOUSE_RELATIVE_MODE_WARP = b"SDL_MOUSE_RELATIVE_MODE_WARP"
 SDL_HINT_MOUSE_RELATIVE_SCALING = b"SDL_MOUSE_RELATIVE_SCALING"
 SDL_HINT_MOUSE_RELATIVE_SPEED_SCALE = b"SDL_MOUSE_RELATIVE_SPEED_SCALE"
+SDL_HINT_MOUSE_RELATIVE_SYSTEM_SCALE = b"SDL_MOUSE_RELATIVE_SYSTEM_SCALE"
 SDL_HINT_MOUSE_RELATIVE_WARP_MOTION = b"SDL_MOUSE_RELATIVE_WARP_MOTION"
 SDL_HINT_MOUSE_TOUCH_EVENTS = b"SDL_MOUSE_TOUCH_EVENTS"
 SDL_HINT_TOUCH_MOUSE_EVENTS = b"SDL_TOUCH_MOUSE_EVENTS"
@@ -280,16 +295,20 @@ SDL_HINT_GAMECONTROLLERTYPE = b"SDL_GAMECONTROLLERTYPE"
 SDL_HINT_GAMECONTROLLER_IGNORE_DEVICES = b"SDL_GAMECONTROLLER_IGNORE_DEVICES"
 SDL_HINT_GAMECONTROLLER_IGNORE_DEVICES_EXCEPT = b"SDL_GAMECONTROLLER_IGNORE_DEVICES_EXCEPT"
 SDL_HINT_GAMECONTROLLER_USE_BUTTON_LABELS = b"SDL_GAMECONTROLLER_USE_BUTTON_LABELS"
+SDL_HINT_HIDAPI_IGNORE_DEVICES = b"SDL_HIDAPI_IGNORE_DEVICES"
 SDL_HINT_JOYSTICK_ALLOW_BACKGROUND_EVENTS = b"SDL_JOYSTICK_ALLOW_BACKGROUND_EVENTS"
 SDL_HINT_JOYSTICK_HIDAPI = b"SDL_JOYSTICK_HIDAPI"
 SDL_HINT_JOYSTICK_HIDAPI_CORRELATE_XINPUT = b"SDL_JOYSTICK_HIDAPI_CORRELATE_XINPUT"
 SDL_HINT_JOYSTICK_HIDAPI_GAMECUBE = b"SDL_JOYSTICK_HIDAPI_GAMECUBE"
 SDL_HINT_JOYSTICK_GAMECUBE_RUMBLE_BRAKE = b"SDL_JOYSTICK_GAMECUBE_RUMBLE_BRAKE"
 SDL_HINT_JOYSTICK_HIDAPI_JOY_CONS = b"SDL_JOYSTICK_HIDAPI_JOY_CONS"
+SDL_HINT_JOYSTICK_HIDAPI_JOYCON_HOME_LED = b"SDL_JOYSTICK_HIDAPI_JOYCON_HOME_LED"
 SDL_HINT_JOYSTICK_HIDAPI_COMBINE_JOY_CONS = b"SDL_JOYSTICK_HIDAPI_COMBINE_JOY_CONS"
+SDL_HINT_JOYSTICK_HIDAPI_VERTICAL_JOY_CONS = b"SDL_JOYSTICK_HIDAPI_VERTICAL_JOY_CONS"
 SDL_HINT_JOYSTICK_HIDAPI_LUNA = b"SDL_JOYSTICK_HIDAPI_LUNA"
 SDL_HINT_JOYSTICK_HIDAPI_NINTENDO_CLASSIC = b"SDL_JOYSTICK_HIDAPI_NINTENDO_CLASSIC"
 SDL_HINT_JOYSTICK_HIDAPI_SHIELD = b"SDL_JOYSTICK_HIDAPI_SHIELD"
+SDL_HINT_JOYSTICK_HIDAPI_PS3 = b"SDL_JOYSTICK_HIDAPI_PS3"
 SDL_HINT_JOYSTICK_HIDAPI_PS4 = b"SDL_JOYSTICK_HIDAPI_PS4"
 SDL_HINT_JOYSTICK_HIDAPI_PS4_RUMBLE = b"SDL_JOYSTICK_HIDAPI_PS4_RUMBLE"
 SDL_HINT_JOYSTICK_HIDAPI_PS5 = b"SDL_JOYSTICK_HIDAPI_PS5"
@@ -299,9 +318,15 @@ SDL_HINT_JOYSTICK_HIDAPI_STADIA = b"SDL_JOYSTICK_HIDAPI_STADIA"
 SDL_HINT_JOYSTICK_HIDAPI_STEAM = b"SDL_JOYSTICK_HIDAPI_STEAM"
 SDL_HINT_JOYSTICK_HIDAPI_SWITCH = b"SDL_JOYSTICK_HIDAPI_SWITCH"
 SDL_HINT_JOYSTICK_HIDAPI_SWITCH_HOME_LED = b"SDL_JOYSTICK_HIDAPI_SWITCH_HOME_LED"
-SDL_HINT_JOYSTICK_HIDAPI_JOYCON_HOME_LED = b"SDL_JOYSTICK_HIDAPI_JOYCON_HOME_LED"
 SDL_HINT_JOYSTICK_HIDAPI_SWITCH_PLAYER_LED = b"SDL_JOYSTICK_HIDAPI_SWITCH_PLAYER_LED"
+SDL_HINT_JOYSTICK_HIDAPI_WII = b"SDL_JOYSTICK_HIDAPI_WII"
+SDL_HINT_JOYSTICK_HIDAPI_WII_PLAYER_LED = b"SDL_JOYSTICK_HIDAPI_WII_PLAYER_LED"
 SDL_HINT_JOYSTICK_HIDAPI_XBOX = b"SDL_JOYSTICK_HIDAPI_XBOX"
+SDL_HINT_JOYSTICK_HIDAPI_XBOX_360 = b"SDL_JOYSTICK_HIDAPI_XBOX_360"
+SDL_HINT_JOYSTICK_HIDAPI_XBOX_360_PLAYER_LED = b"SDL_JOYSTICK_HIDAPI_XBOX_360_PLAYER_LED"
+SDL_HINT_JOYSTICK_HIDAPI_XBOX_360_WIRELESS = b"SDL_JOYSTICK_HIDAPI_XBOX_360_WIRELESS"
+SDL_HINT_JOYSTICK_HIDAPI_XBOX_ONE = b"SDL_JOYSTICK_HIDAPI_XBOX_ONE"
+SDL_HINT_JOYSTICK_HIDAPI_XBOX_ONE_HOME_LED = b"SDL_JOYSTICK_HIDAPI_XBOX_ONE_HOME_LED"
 SDL_HINT_JOYSTICK_RAWINPUT = b"SDL_JOYSTICK_RAWINPUT"
 SDL_HINT_JOYSTICK_RAWINPUT_CORRELATE_XINPUT = b"SDL_JOYSTICK_RAWINPUT_CORRELATE_XINPUT"
 SDL_HINT_JOYSTICK_ROG_CHAKRAM = b"SDL_JOYSTICK_ROG_CHAKRAM"
@@ -321,6 +346,7 @@ SDL_HINT_LINUX_JOYSTICK_DEADZONES = b"SDL_LINUX_JOYSTICK_DEADZONES"
 SDL_HINT_MAC_BACKGROUND_APP = b"SDL_MAC_BACKGROUND_APP"
 SDL_HINT_MAC_CTRL_CLICK_EMULATE_RIGHT_CLICK = b"SDL_MAC_CTRL_CLICK_EMULATE_RIGHT_CLICK"
 SDL_HINT_MAC_OPENGL_ASYNC_DISPATCH = b"SDL_MAC_OPENGL_ASYNC_DISPATCH"
+SDL_HINT_PS2_DYNAMIC_VSYNC = b"SDL_PS2_DYNAMIC_VSYNC"
 SDL_HINT_RPI_VIDEO_LAYER = b"SDL_RPI_VIDEO_LAYER"
 SDL_HINT_RENDER_DIRECT3D11_DEBUG = b"SDL_RENDER_DIRECT3D11_DEBUG"
 SDL_HINT_RENDER_DIRECT3D_THREADSAFE = b"SDL_RENDER_DIRECT3D_THREADSAFE"
@@ -381,10 +407,12 @@ _funcdefs = [
     SDLFunc("SDL_SetHintWithPriority", [c_char_p, c_char_p, SDL_HintPriority], SDL_bool),
     SDLFunc("SDL_SetHint", [c_char_p, c_char_p], SDL_bool),
     SDLFunc("SDL_GetHint", [c_char_p], c_char_p),
+    SDLFunc("SDL_ResetHint", [c_char_p], SDL_bool, added='2.24.0'),
+    SDLFunc("SDL_ResetHints", None, None, added='2.26.0'),
     SDLFunc("SDL_GetHintBoolean", [c_char_p, SDL_bool], SDL_bool, added='2.0.5'),
     SDLFunc("SDL_ClearHints"),
     SDLFunc("SDL_AddHintCallback", [c_char_p, SDL_HintCallback, c_void_p]),
-    SDLFunc("SDL_DelHintCallback",[c_char_p, SDL_HintCallback, c_void_p]),
+    SDLFunc("SDL_DelHintCallback", [c_char_p, SDL_HintCallback, c_void_p]),
 ]
 _ctypes = AttributeDict()
 for f in _funcdefs:
@@ -397,6 +425,8 @@ for f in _funcdefs:
 SDL_SetHintWithPriority = _ctypes["SDL_SetHintWithPriority"]
 SDL_SetHint = _ctypes["SDL_SetHint"]
 SDL_GetHint = _ctypes["SDL_GetHint"]
+SDL_ResetHint = _ctypes["SDL_ResetHint"]
+SDL_ResetHints = _ctypes["SDL_ResetHints"]
 SDL_GetHintBoolean = _ctypes["SDL_GetHintBoolean"]
 SDL_ClearHints = _ctypes["SDL_ClearHints"]
 SDL_AddHintCallback = _ctypes["SDL_AddHintCallback"]
