@@ -333,6 +333,7 @@ _funcdefs = [
         [_P(SDL_Window), _P(c_int), _P(c_int), _P(c_int), _P(c_int)],
         returns = c_int, added = '2.0.5'
     ),
+    SDLFunc("SDL_GetWindowSizeInPixels", [_P(SDL_Window), _P(c_int), _P(c_int)], added='2.26.0'),
     SDLFunc("SDL_SetWindowMinimumSize", [_P(SDL_Window), c_int, c_int]),
     SDLFunc("SDL_GetWindowMinimumSize", [_P(SDL_Window), _P(c_int), _P(c_int)]),
     SDLFunc("SDL_SetWindowMaximumSize", [_P(SDL_Window), c_int, c_int]),
@@ -433,6 +434,7 @@ SDL_SetWindowPosition = _ctypes["SDL_SetWindowPosition"]
 SDL_GetWindowPosition = _ctypes["SDL_GetWindowPosition"]
 SDL_SetWindowSize = _ctypes["SDL_SetWindowSize"]
 SDL_GetWindowSize = _ctypes["SDL_GetWindowSize"]
+SDL_GetWindowSizeInPixels = _ctypes["SDL_GetWindowSizeInPixels"]
 SDL_SetWindowMinimumSize = _ctypes["SDL_SetWindowMinimumSize"]
 SDL_GetWindowMinimumSize = _ctypes["SDL_GetWindowMinimumSize"]
 SDL_SetWindowMaximumSize = _ctypes["SDL_SetWindowMaximumSize"]
